Index: trunk/MagicSoft/Mars/mhbase/MHMatrix.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8074)
@@ -30,5 +30,5 @@
 //
 // This is a histogram container which holds a matrix with one column per
-// data variable. The data variable can be a complex rule (MDataChain).
+// data variable. The data variable can be a complex rule (MDataPhrase).
 // Each event for wich Fill is called (by MFillH) is added as a new
 // row to the matrix.

Index: trunk/MagicSoft/Mars/mhbase/MFillH.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 8074)
@@ -84,5 +84,5 @@
 #include <TCanvas.h>
 
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 
 #include "MLog.h"
@@ -292,5 +292,5 @@
 //
 // If the histogram to be filles is a MHArray you can specify a 'rule'
 // This rule is used to create an MDataChain. The return value of the chain
 // is casted to int. Each int acts as a key. For each (new) key a new
 // histogram is created in the array. (eg for the rule
@@ -299,5 +299,5 @@
 void MFillH::SetRuleForIdx(const TString rule)
 {
-    fIndex = new MDataChain(rule);
+    fIndex = new MDataPhrase(rule);
     fIndex->SetBit(kCanDelete);
 }
@@ -562,5 +562,5 @@
 //    if (save && fCanvas)
 //        save->cd();
-    return rc;
+    return rc==kFALSE ? kCONTINUE : kTRUE;
 } 
 
@@ -292,5 +292,5 @@
 //
 // If the histogram to be filles is a MHArray you can specify a 'rule'
-// This rule is used to create an MDataChain. The return value of the chain
+// This rule is used to create an MDataPhrase. The return value of the chain
 // is casted to int. Each int acts as a key. For each (new) key a new
 // histogram is created in the array. (eg for the rule